==> shellcheck-0.5.0-135-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.5.0
id: ShellCheck-0.5.0-BPrEx8WWTamJM5gQQ6fxr
key: ShellCheck-0.5.0-BPrEx8WWTamJM5gQQ6fxr
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: b5d3cc71cd2aae4f65f5aa1c4655642c
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.6.1/site-local/ShellCheck-0.5.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/ShellCheck-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/ShellCheck-0.5.0
hs-libraries: HSShellCheck-0.5.0-BPrEx8WWTamJM5gQQ6fxr
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc
    aeson-1.4.1.0-BaRGy5iBSXU37DPvV6hbuH base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    parsec-3.1.13.0 process-1.6.3.0
    regex-tdfa-1.2.3.1-CGhC8CUtNjDA8FgpdYb1ua
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.5.0-147-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.5.0
id: ShellCheck-0.5.0-7NqS9f0PXWeAjdbwniyW0M
key: ShellCheck-0.5.0-7NqS9f0PXWeAjdbwniyW0M
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: e5234b1f914693f460da68c2095ff3de
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.6.2/site-local/ShellCheck-0.5.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/ShellCheck-0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/ShellCheck-0.5.0
hs-libraries: HSShellCheck-0.5.0-7NqS9f0PXWeAjdbwniyW0M
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc
    aeson-1.4.1.0-LhGJkSbQXa4Bc1ggOsS4Ag base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    parsec-3.1.13.0 process-1.6.3.0
    regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
